@@ -73,7 +73,7 @@ class ClinicalQualityMeasure130v6(ExternallyAwareClinicalQualityMeasure, Clinica
     in "Procedure, Performed" template or "Diagnostic Study, Performed" template in QRDA-1. Patient
     self-report is not allowed for laboratory tests.
 
-    More information: https://ecqi.healthit.gov/ecqm/measures/cms130v6
+    More information: https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS130v6.html
     """
 
     class Meta:
@@ -84,7 +84,7 @@ class ClinicalQualityMeasure130v6(ExternallyAwareClinicalQualityMeasure, Clinica
         description = (
             'Adults 50-75 years of age who have not had appropriate screening for colorectal cancer.'
         )
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms130v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS130v6.html'
 
         identifiers = ['CMS130v6']
 
@@ -374,7 +374,7 @@ class ClinicalQualityMeasure130v6(ExternallyAwareClinicalQualityMeasure, Clinica
                 patient=self.patient,
                 referral=FlexibleSigmoidoscopy,
                 context={
-                    **context, 'specialties': ['Gastroenterology',]
+                    **context, 'specialties': ['Gastroenterology', ]
                 },
                 title='Order a Flexible sigmoidoscopy'))
 
@@ -386,7 +386,7 @@ class ClinicalQualityMeasure130v6(ExternallyAwareClinicalQualityMeasure, Clinica
                 patient=self.patient,
                 imaging=CtColonography,
                 context={
-                    **context, 'specialties': ['Radiology',]
+                    **context, 'specialties': ['Radiology', ]
                 },
                 title='Order a CT Colonography'))
 
@@ -398,7 +398,7 @@ class ClinicalQualityMeasure130v6(ExternallyAwareClinicalQualityMeasure, Clinica
                 patient=self.patient,
                 referral=Colonoscopy,
                 context={
-                    **context, 'specialties': ['Gastroenterology',]
+                    **context, 'specialties': ['Gastroenterology', ]
                 },
                 title='Order a Colonoscopy'))
 
