@@ -677,6 +677,7 @@ class ClinicalQualityMeasure130v6Test(SDKBaseTest):
         }])  # yapf: disable
         patient.referral_reports[0]['originalDate'] = '2019-07-26'
         patient.billing_line_items[0]['created'] = '2019-07-26'
+        patient.billing_line_items[0]['datetimeOfService'] = '2019-07-26'
 
         # exam done within the last 180 days
         tested = ClinicalQualityMeasure130v6(
@@ -690,6 +691,7 @@ class ClinicalQualityMeasure130v6Test(SDKBaseTest):
 
         # exam done 181 days
         patient.billing_line_items[0]['created'] = '2028-07-29'  # visit within the 180-day period
+        patient.billing_line_items[0]['datetimeOfService'] = '2028-07-29'  # visit within the 180-day period
         tested = ClinicalQualityMeasure130v6(
             patient=patient, now=arrow.get('2028-07-26').shift(days=181))
         result = tested.compute_results()
