@@ -16,7 +16,7 @@ import string
 from canvas_workflow_kit import settings
 from canvas_workflow_kit.api import fetch_patient
 from canvas_workflow_kit.patient import Patient
-from canvas_workflow_kit.protocol import CONTEXT_REPORT
+from canvas_workflow_kit.protocol import CONTEXT_REPORT, CONTEXT_GUIDANCE
 from canvas_workflow_kit.timeframe import Timeframe
 from canvas_workflow_kit.internal.string import snakecase
 from canvas_workflow_kit.utils import (
@@ -242,7 +242,9 @@ def test_patient(
     # 3. instantiate module
     protocol = Class(patient=patient, date=date, timeframe=timeframe)
     if report_mode:
-        protocol.context == CONTEXT_REPORT
+        protocol.context = CONTEXT_REPORT
+    else:
+        protocol.context = CONTEXT_GUIDANCE
 
     results = protocol.compute_results()
 
