@@ -790,6 +790,10 @@ class TaskRecordSet(PatientRecordSet):
     PATIENT_FIELD = 'tasks'
     API_UPDATE_FIELD = 'tasks'
 
+class AppointmentRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'appointments'
+    API_UPDATE_FIELD = 'appointments'
 
 class UpcomingAppointmentRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['canvas', 'internal']
