@@ -1,6 +1,9 @@
 from canvas_workflow_kit.intervention import Intervention
 from canvas_workflow_kit.patient import Patient
 from canvas_workflow_kit.recommendation import (
+    AllergyRecommendation,
+    DiagnoseRecommendation,
+    FollowUpRecommendation,
     HyperlinkRecommendation,
     ImagingRecommendation,
     ImmunizationRecommendation,
@@ -79,6 +82,98 @@ class RecommendationTest(SDKBaseTest):
         HelperCommand().equal_commands(expected, result)
 
 
+class AllergyRecommendationTest(SDKBaseTest):
+    def test__init__(self):
+        class AllergyTestValueSet(ValueSet):
+            VALUE_SET_NAME = 'Enterococcus faecalis'
+            FDB = {'1226'}
+
+        rec = AllergyRecommendation(
+            key='ALLERGY', rank=1, button='Allergy', allergy=AllergyTestValueSet,
+            narrative='rash and hives', context={'severity': 'mild', 'onset_date': '2020-01-01'})
+        self.assertIsInstance(rec, Recommendation)
+        self.assertEqual(rec.key, 'ALLERGY')
+        self.assertEqual(rec.rank, 1)
+        self.assertEqual(rec.button, 'Allergy')
+        self.assertEqual(rec.title, 'Enterococcus faecalis')
+        self.assertEqual(rec.narrative, 'rash and hives')
+        self.assertEqual(rec.context['severity'], 'mild')
+        self.assertEqual(rec.context['onset_date'], '2020-01-01')
+
+        expected = {
+            'type': 'allergy',
+            'filter': {
+                'coding': [{
+                    'system': 'fdb',
+                    'code': ['1226']
+                }]
+            }
+        }
+        result = rec.command
+        HelperCommand().equal_commands(expected, result)
+
+
+class DiagnoseRecommendationTest(SDKBaseTest):
+    def test__init__(self):
+        patient = self.load_patient('full')
+        self.assertIsInstance(patient, Patient)
+
+        class DiagnoseTestValueSet(ValueSet):
+            VALUE_SET_NAME = 'Senile purpura'
+            ICD10CM = {'D692'}
+            INTERNAL = {'PAT.QUES.8'}
+
+        rec = DiagnoseRecommendation(
+            key='DIAGNOSE', rank=1, button='Diagnose', patient=patient,
+            condition=DiagnoseTestValueSet)
+        self.assertIsInstance(rec, Recommendation)
+        self.assertEqual(rec.key, 'DIAGNOSE')
+        self.assertEqual(rec.rank, 1)
+        self.assertEqual(rec.button, 'Diagnose')
+        self.assertEqual(rec.title, 'Senile purpura')
+        self.assertEqual(rec.narrative, 'Consider diagnosing Darey with Senile purpura')
+
+        expected = {
+            'type': 'diagnose',
+            'filter': {
+                'coding': [{
+                    'system': 'icd10cm',
+                    'code': ['D692']
+                }, {
+                    'system': 'internal',
+                    'code': ['PAT.QUES.8']
+                }]
+            }
+        }
+        result = rec.command
+        HelperCommand().equal_commands(expected, result)
+
+
+class FollowUpRecommendationTest(SDKBaseTest):
+    def test__init__(self):
+        patient = self.load_patient('full')
+        self.assertIsInstance(patient, Patient)
+
+        rec = FollowUpRecommendation(
+            key='FOLLOWUP', rank=1, button='Follow Up', patient=patient,
+            title='Request follow up office visit on 3/5/22',
+            context={'requested_appointment_type': 'office', 'requested_date': '2022-03-05',
+                     'reason_for_visit': 'covid vaccine booster',
+                     'internal_comment': 'make sure he brings his covid vaccination card'})
+        self.assertIsInstance(rec, Recommendation)
+        self.assertEqual(rec.key, 'FOLLOWUP')
+        self.assertEqual(rec.rank, 1)
+        self.assertEqual(rec.button, 'Follow Up')
+        self.assertEqual(rec.title, 'Request follow up office visit on 3/5/22')
+        self.assertEqual(rec.narrative, 'Darey needs a follow-up appointment')
+        self.assertEqual(rec.context['requested_appointment_type'], 'office')
+        self.assertEqual(rec.context['requested_date'], '2022-03-05')
+        self.assertEqual(
+            rec.context['internal_comment'],
+            'make sure he brings his covid vaccination card')
+        self.assertEqual(rec.command, {'type': 'followUp'})
+
+
 class ImagingRecommendationTest(SDKBaseTest):
 
     def test___init__(self):
@@ -86,7 +181,8 @@ class ImagingRecommendationTest(SDKBaseTest):
         self.assertIsInstance(patient, Patient)
 
         rec = ImagingRecommendation(
-            key='KEY-ID', rank=123, button='ACT', patient=patient, imaging=CtColonography)
+            key='KEY-ID', rank=123, button='ACT', patient=patient, imaging=CtColonography,
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -98,6 +194,8 @@ class ImagingRecommendationTest(SDKBaseTest):
         expected = 'Order CT Colonography'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'imagingOrder',
             'filter': {
@@ -120,8 +218,8 @@ class ReferRecommendationTest(SDKBaseTest):
         patient = self.load_patient('full')
         self.assertIsInstance(patient, Patient)
 
-        rec = ReferRecommendation(
-            key='KEY-ID', rank=123, button='ACT', patient=patient, referral=FitDna)
+        rec = ReferRecommendation(key='KEY-ID', rank=123, button='ACT',
+                                  patient=patient, referral=FitDna, context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -133,6 +231,8 @@ class ReferRecommendationTest(SDKBaseTest):
         expected = 'Refer FIT DNA'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'refer',
             'filter': {
@@ -158,7 +258,8 @@ class LabRecommendationTest(SDKBaseTest):
             button='ACT',
             patient=patient,
             lab=Hba1CLaboratoryTest,
-            condition=Diabetes)
+            condition=Diabetes,
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -170,6 +271,8 @@ class LabRecommendationTest(SDKBaseTest):
         expected = 'Order HbA1c Laboratory Test'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'labOrder',
             'filter': {
@@ -194,7 +297,8 @@ class ImmunizationRecommendationTest(SDKBaseTest):
             rank=123,
             button='ACT',
             patient=patient,
-            immunization=InfluenzaVaccine_1254)
+            immunization=InfluenzaVaccine_1254,
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -206,6 +310,8 @@ class ImmunizationRecommendationTest(SDKBaseTest):
         expected = 'Order Influenza Vaccine'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'immunization',
             'filter': {
@@ -229,7 +335,8 @@ class InstructionRecommendationTest(SDKBaseTest):
         self.assertIsInstance(patient, Patient)
 
         rec = InstructionRecommendation(
-            key='KEY-ID', rank=123, button='ACT', patient=patient, instruction=AboveNormalFollowUp)
+            key='KEY-ID', rank=123, button='ACT', patient=patient, instruction=AboveNormalFollowUp,
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -241,6 +348,8 @@ class InstructionRecommendationTest(SDKBaseTest):
         expected = 'Instruct Above Normal Follow-up'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'instruct',
             'filter': {
@@ -284,7 +393,8 @@ class InterviewRecommendationTest(SDKBaseTest):
             rank=123,
             button='ACT',
             patient=patient,
-            questionnaires=[TobaccoUseScreening, LimitedLifeExpectancy])
+            questionnaires=[TobaccoUseScreening, LimitedLifeExpectancy],
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -296,6 +406,8 @@ class InterviewRecommendationTest(SDKBaseTest):
         expected = 'Interview Tobacco Use Screening, Limited Life Expectancy'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'interview',
             'filter': {
@@ -323,7 +435,8 @@ class PrescribeRecommendationTest(SDKBaseTest):
             rank=123,
             button='ACT',
             patient=patient,
-            prescription=TobaccoUseCessationPharmacotherapy)
+            prescription=TobaccoUseCessationPharmacotherapy,
+            context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -335,6 +448,8 @@ class PrescribeRecommendationTest(SDKBaseTest):
         expected = 'Prescribe Tobacco Use Cessation Pharmacotherapy'
         self.assertEqual(expected, rec.title)
 
+        self.assertEqual(rec.context['foo'], 'bar')
+
         expected = {
             'type': 'prescribe',
             'filter': {
@@ -361,7 +476,8 @@ class VitalSignRecommendationTest(SDKBaseTest):
         patient = self.load_patient('full')
         self.assertIsInstance(patient, Patient)
 
-        rec = VitalSignRecommendation(key='KEY-ID', rank=123, button='ACT', patient=patient)
+        rec = VitalSignRecommendation(key='KEY-ID', rank=123, button='ACT',
+                                      patient=patient, context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -369,6 +485,7 @@ class VitalSignRecommendationTest(SDKBaseTest):
         self.assertEqual('Darey should vital signs collected.', rec.narrative)
         self.assertEqual('Collect vitals', rec.title)
         self.assertEqual({'type': 'vitalSign'}, rec.command)
+        self.assertEqual(rec.context['foo'], 'bar')
 
 
 class PlanRecommendationTest(SDKBaseTest):
@@ -377,7 +494,8 @@ class PlanRecommendationTest(SDKBaseTest):
         patient = self.load_patient('full')
         self.assertIsInstance(patient, Patient)
 
-        rec = PlanRecommendation(key='KEY-ID', rank=123, button='ACT', patient=patient)
+        rec = PlanRecommendation(key='KEY-ID', rank=123, button='ACT',
+                                 patient=patient, context={'foo': 'bar'})
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
         self.assertEqual(rec.rank, 123)
@@ -385,6 +503,7 @@ class PlanRecommendationTest(SDKBaseTest):
         self.assertEqual('Darey should have a plan.', rec.narrative)
         self.assertEqual('Make a plan', rec.title)
         self.assertEqual({'type': 'plan'}, rec.command)
+        self.assertEqual(rec.context['foo'], 'bar')
 
 
 class TaskRecommendationTest(SDKBaseTest):
@@ -393,8 +512,8 @@ class TaskRecommendationTest(SDKBaseTest):
         patient = self.load_patient('full')
         self.assertIsInstance(patient, Patient)
 
-        rec = TaskRecommendation(
-            key='KEY-ID', rank=123, title='TITLE', button='ACT', patient=patient)
+        rec = TaskRecommendation(key='KEY-ID', rank=123, title='TITLE',
+                                 button='ACT', patient=patient, context={'foo': 'bar'})
 
         self.assertIsInstance(rec, Recommendation)
         self.assertEqual(rec.key, 'KEY-ID')
@@ -403,6 +522,7 @@ class TaskRecommendationTest(SDKBaseTest):
         self.assertEqual(rec.button, 'ACT')
         self.assertIsNone(rec.narrative)
         self.assertEqual({'type': 'task'}, rec.command)
+        self.assertEqual(rec.context['foo'], 'bar')
 
 
 class HyperlinkRecommendationTest(SDKBaseTest):
